==> ejc-proequipmentp-impl-3.0.0-20220707.014120-161-sources.jar: com/ejianc/business/asset/bean/HandleEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 *  设备处置
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipment_handle")
public class HandleEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="handle_date")
    private Date handleDate; // 处置日期
    @TableField(value="handle_person")
    private String handlePerson; // 处置人
    @TableField(value="handle_person_name")
    private Long handlePersonName; // 处置人id
    @TableField(value="org_id")
    private Long orgId; // 所属项目部Id
    @TableField(value="org_name")
    private String orgName; // 所属项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="amortize_type")
    private String amortizeType; // 摊销方式
    @TableField(value="handle_tax_mny")
    private BigDecimal handleTaxMny; // 处置金额(含税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="handle_mny")
    private BigDecimal handleMny; // 处置金额
    @TableField(value="handle_type")
    private Integer handleType; // 处置类型 1：正常处置 2：非正常处置
    @TableField(value="handle_reason")
    private Long handleReason; // 处置原因id
    @TableField(value="handle_reason_name")
    private String handleReasonName; // 处置原因
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_name")
    private String employeeName; // 经办人
    @TableField(value="department_id")
    private Long departmentId; // 经办人部门id
    @TableField(value="department_name")
    private String departmentName; //  经办人部门
    @TableField(value="source")
    private Integer source; // 来源 1：自制 2:财务推送
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getHandleDate() {
        return handleDate;
    }

    public void setHandleDate(Date handleDate) {
        this.handleDate = handleDate;
    }
    public String getHandlePerson() {
        return handlePerson;
    }

    public void setHandlePerson(String handlePerson) {
        this.handlePerson = handlePerson;
    }
    public Long getHandlePersonName() {
        return handlePersonName;
    }

    public void setHandlePersonName(Long handlePersonName) {
        this.handlePersonName = handlePersonName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getAmortizeType() {
        return amortizeType;
    }

    public void setAmortizeType(String amortizeType) {
        this.amortizeType = amortizeType;
    }
    public BigDecimal getHandleTaxMny() {
        return handleTaxMny;
    }

    public void setHandleTaxMny(BigDecimal handleTaxMny) {
        this.handleTaxMny = handleTaxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getHandleMny() {
        return handleMny;
    }

    public void setHandleMny(BigDecimal handleMny) {
        this.handleMny = handleMny;
    }
    public Integer getHandleType() {
        return handleType;
    }

    public void setHandleType(Integer handleType) {
        this.handleType = handleType;
    }
    public Long getHandleReason() {
        return handleReason;
    }

    public void setHandleReason(Long handleReason) {
        this.handleReason = handleReason;
    }
    public String getHandleReasonName() {
        return handleReasonName;
    }

    public void setHandleReasonName(String handleReasonName) {
        this.handleReasonName = handleReasonName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Integer getSource() {
        return source;
    }

    public void setSource(Integer source) {
        this.source = source;
    }
    
}

==> ejc-proequipmentp-impl-3.0.0-20220708.083110-170-sources.jar: com/ejianc/business/asset/bean/HandleEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 *  设备处置
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipment_handle")
public class HandleEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="handle_date")
    private Date handleDate; // 处置日期
    @TableField(value="handle_person_name")
    private String handlePersonName; // 处置人
    @TableField(value="handle_person")
    private Long handlePerson; // 处置人id
    @TableField(value="org_id")
    private Long orgId; // 所属项目部Id
    @TableField(value="org_name")
    private String orgName; // 所属项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="amortize_type")
    private Integer amortizeType; // 摊销方式
    @TableField(value="amortize_type_code")
    private Integer amortizeTypeCode; // 摊销方式编码
    @TableField(value="handle_tax_mny")
    private BigDecimal handleTaxMny; // 处置金额(含税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="handle_mny")
    private BigDecimal handleMny; // 处置金额
    @TableField(value="handle_type")
    private Integer handleType; // 处置类型 1：正常处置 2：非正常处置
    @TableField(value="handle_reason")
    private Long handleReason; // 处置原因id
    @TableField(value="handle_reason_name")
    private String handleReasonName; // 处置原因
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_name")
    private String employeeName; // 经办人
    @TableField(value="department_id")
    private Long departmentId; // 经办人部门id
    @TableField(value="department_name")
    private String departmentName; //  经办人部门
    @TableField(value="source")
    private Integer source; // 来源 1：自制 2:财务推送
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getHandleDate() {
        return handleDate;
    }

    public void setHandleDate(Date handleDate) {
        this.handleDate = handleDate;
    }

    public String getHandlePersonName() {
        return handlePersonName;
    }

    public void setHandlePersonName(String handlePersonName) {
        this.handlePersonName = handlePersonName;
    }

    public Long getHandlePerson() {
        return handlePerson;
    }

    public void setHandlePerson(Long handlePerson) {
        this.handlePerson = handlePerson;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Integer getAmortizeType() {
        return amortizeType;
    }

    public void setAmortizeType(Integer amortizeType) {
        this.amortizeType = amortizeType;
    }

    public Integer getAmortizeTypeCode() {
        return amortizeTypeCode;
    }

    public void setAmortizeTypeCode(Integer amortizeTypeCode) {
        this.amortizeTypeCode = amortizeTypeCode;
    }

    public BigDecimal getHandleTaxMny() {
        return handleTaxMny;
    }

    public void setHandleTaxMny(BigDecimal handleTaxMny) {
        this.handleTaxMny = handleTaxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getHandleMny() {
        return handleMny;
    }

    public void setHandleMny(BigDecimal handleMny) {
        this.handleMny = handleMny;
    }
    public Integer getHandleType() {
        return handleType;
    }

    public void setHandleType(Integer handleType) {
        this.handleType = handleType;
    }
    public Long getHandleReason() {
        return handleReason;
    }

    public void setHandleReason(Long handleReason) {
        this.handleReason = handleReason;
    }
    public String getHandleReasonName() {
        return handleReasonName;
    }

    public void setHandleReasonName(String handleReasonName) {
        this.handleReasonName = handleReasonName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Integer getSource() {
        return source;
    }

    public void setSource(Integer source) {
        this.source = source;
    }
    
}
